@@ -2,11 +2,11 @@
 
 set -x
 glib-gettextize --copy --force
-libtoolize --automake
+libtoolize --copy --force --automake
 intltoolize --copy --force --automake
 
-aclocal-1.8
+aclocal-1.9
 autoconf
 autoheader
-automake-1.8 --add-missing --foreign
+automake-1.9 --add-missing --foreign
 ./configure --enable-maintainer-mode
